sqlite3_ext_main

Attribute Macro sqlite3_ext_main 

#[sqlite3_ext_main]
Declare the primary extension entry point for the crate.

This is equivalent to sqlite3_ext_init, but it will automatically name the export according to the name of the crate (e.g. sqlite3_myextension_init).

Examples

Specify a persistent extension:

use sqlite3_ext::*;

#[sqlite3_ext_main(persistent)]
fn init(db: &Connection) -> Result<()> {
    Ok(())
}